@@ -33,6 +33,7 @@ class BarOptionWidget : public OptionWidget
 
 	public:
 		BarOptionWidget(QWidget *parent = 0);
+		~BarOptionWidget();
 
 		void construct();
 
@@ -43,6 +44,8 @@ class BarOptionWidget : public OptionWidget
 
 		void init();
 		void apply();
+		void setWidget();
+		Bar *bar;
 		QRadioButton *barSizeRadioButton;
 		QDoubleSpinBox *barSizeDoubleSpinBox;
 		QRadioButton *synRadioButton;
