@@ -32,6 +32,7 @@ class BoxWidthOptionWidget : public OptionWidget
 
 	public:
 		BoxWidthOptionWidget(QWidget *parent = 0);
+		~BoxWidthOptionWidget();
 
 		void construct();
 
@@ -42,6 +43,8 @@ class BoxWidthOptionWidget : public OptionWidget
 
 		void init();
 		void apply();
+		void setWidget();
+		BoxWidth *boxWidth;
 		QCheckBox *defaultCheckBox;
 		QDoubleSpinBox *boxWidthDoubleSpinBox;
 		QCheckBox *absoluteCheckBox;
