@@ -31,6 +31,7 @@ class DummyOptionWidget : public OptionWidget
 
 	public:
 		DummyOptionWidget(QWidget *parent = 0);
+		~DummyOptionWidget();
 
 		void construct();
 
@@ -41,7 +42,9 @@ class DummyOptionWidget : public OptionWidget
 
 		void init();
 		void apply();
-		static const int AXIS_NUM = 2;
-		QLineEdit *dummyLineEdit[AXIS_NUM];
+		void setWidget();
+		Dummy *dummy;
+		QLineEdit *xDummyLineEdit;
+		QLineEdit *yDummyLineEdit;
 };
 #endif // DUMMY_OPTION_WIDGET_INCLUDED
