@@ -23,6 +23,7 @@
 
 class LogScale;
 
+#include <QList>
 class QCheckBox;
 class QLineEdit;
 
@@ -32,6 +33,7 @@ class LogScaleOptionWidget : public OptionWidget
 
 	public:
 		LogScaleOptionWidget(QWidget *parent = 0);
+		~LogScaleOptionWidget();
 
 		void construct();
 
@@ -42,8 +44,9 @@ class LogScaleOptionWidget : public OptionWidget
 
 		void init();
 		void apply();
-		static const int TICS_NUM = 5;
-		QCheckBox *logScaleCheckBox[TICS_NUM];
-		QLineEdit *baseLineEdit[TICS_NUM];
+		void setWidget();
+		LogScale *logScale;
+		QList<QCheckBox *> logScaleCheckBoxList;
+		QList<QLineEdit *> baseLineEditList;
 };
 #endif // LOG_SCALE_OPTION_WIDGET_INCLUDED
