@@ -26,3 +26,8 @@ OptionWidget::OptionWidget(QWidget *parent)
 OptionWidget::~OptionWidget()
 {
 }
+
+void OptionWidget::discard()
+{
+	setWidget();
+}
