@@ -30,13 +30,16 @@ class OptionWidget : public QWidget
 		virtual ~OptionWidget();
 
 		virtual void construct() = 0;
-
-	public slots:
 		virtual void init() = 0;
 		virtual void apply() = 0;
+		void discard();
 
 	signals:
 		void executed(const QString &command);
+		void modified();
+
+	protected:
+		virtual void setWidget() = 0;
 
 	private:
 		// don't implement these
