@@ -33,6 +33,7 @@ class OutputOptionWidget : public OptionWidget
 
 	public:
 		OutputOptionWidget(QWidget *parent = 0);
+		~OutputOptionWidget();
 
 		void construct();
 
@@ -46,6 +47,8 @@ class OutputOptionWidget : public OptionWidget
 
 		void init();
 		void apply();
+		void setWidget();
+		Output *output;
 		QString currentFile;
 		QCheckBox *defaultCheckBox;
 		QLineEdit *fileNameLineEdit;
