@@ -32,6 +32,7 @@ class SizeOptionWidget : public OptionWidget
 
 	public:
 		SizeOptionWidget(QWidget *parent = 0);
+		~SizeOptionWidget();
 
 		void construct();
 
@@ -42,6 +43,8 @@ class SizeOptionWidget : public OptionWidget
 
 		void init();
 		void apply();
+		void setWidget();
+		Size *size;
 		QCheckBox *ratioCheckBox;
 		QDoubleSpinBox *ratioDoubleSpinBox;
 		QDoubleSpinBox *hSizeDoubleSpinBox;
