@@ -31,11 +31,16 @@ int main(int argc, char *argv[])
 
 	QApplication app(argc, argv);
 
-	QTranslator translator;
-	translator.load(QCoreApplication::applicationName().toLower() + "_" 
+	QTranslator qtTranslator;
+	qtTranslator.load("qt_" + QLocale::system().name(),
+			QCoreApplication::applicationDirPath());
+	app.installTranslator(&qtTranslator);
+
+	QTranslator appTranslator;
+	appTranslator.load(QCoreApplication::applicationName().toLower() + "_" 
 			+ QLocale::system().name(),
 			QCoreApplication::applicationDirPath());
-	app.installTranslator(&translator);
+	app.installTranslator(&appTranslator);
 
 	MainWindow mainWindow;
 	mainWindow.show();
