@@ -21,6 +21,7 @@
 
 #include "Option.h"
 
+#include <QList>
 #include <QString>
 
 class LogScale : public Option
@@ -35,10 +36,11 @@ class LogScale : public Option
 		const QString &base(int axis) const;
 
 		QString command() const;
+
+		static const QString AXIS[];
 	private:
 		static const double DEFAULT_BASE;
-		static const int AXIS_NUM = 6;
-		bool flagArray[AXIS_NUM];
-		QString baseArray[AXIS_NUM];
+		QList<bool> flagList;
+		QList<QString> baseList;
 };
 #endif // LOG_SCALE_INCLUDED
